summaryrefslogtreecommitdiffstats
path: root/src/htmlexporter.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/htmlexporter.cpp')
-rw-r--r--src/htmlexporter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/htmlexporter.cpp b/src/htmlexporter.cpp
index f9ef3d3..70e0f59 100644
--- a/src/htmlexporter.cpp
+++ b/src/htmlexporter.cpp
@@ -44,7 +44,7 @@ HTMLExporter::HTMLExporter(Basket *basket)
TQDir dir;
// Compute a default file name & path:
- KConfig *config = TDEGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup("Export to HTML");
TQString folder = config->readEntry("lastFolder", TQDir::homeDirPath()) + "/";
TQString url = folder + TQString(basket->basketName()).replace("/", "_") + ".html";
@@ -550,11 +550,11 @@ TQString HTMLExporter::copyFile(const TQString &srcPath, bool createIt)
if (file.open(IO_WriteOnly))
file.close();
// And then we copy the file AND overwriting the file we juste created:
- new KIO::FileCopyJob(
+ new TDEIO::FileCopyJob(
KURL(srcPath), KURL(fullPath), 0666, /*move=*/false,
/*overwrite=*/true, /*resume=*/true, /*showProgress=*/false );
} else
/*KIO::CopyJob *copyJob = */KIO::copy(KURL(srcPath), KURL(fullPath)); // Do it as before
return fileName;
}
@@ -550,11 +550,11 @@ TQString HTMLExporter::copyFile(const TQString &srcPath, bool createIt)
/*overwrite=*/true, /*resume=*/true, /*showProgress=*/false );
} else
- /*KIO::CopyJob *copyJob = */KIO::copy(KURL(srcPath), KURL(fullPath)); // Do it as before
+ /*TDEIO::CopyJob *copyJob = */TDEIO::copy(KURL(srcPath), KURL(fullPath)); // Do it as before
return fileName;
}